pub struct OverlayBuilder<N: NodePrimitives = EthPrimitives> { /* private fields */ }Expand description
Builder for calculating trie and hashed-state overlays.
This stores the overlay manager, overlay configuration, and the logic for resolving overlays and collecting reverts.
Implementations
Sourceimpl<N: NodePrimitives> OverlayBuilder<N>
impl<N: NodePrimitives> OverlayBuilder<N>
Sourcepub fn with_overlay_source(self, source: Option<OverlaySource>) -> Self
pub fn with_overlay_source(self, source: Option<OverlaySource>) -> Self
Set the overlay source.
This overlay will be applied on top of any reverts.
Sourcepub const fn with_skip_overlay_for_reused_sparse_trie(
self,
anchor_hash: B256,
) -> Self
pub const fn with_skip_overlay_for_reused_sparse_trie( self, anchor_hash: B256, ) -> Self
Skips managed overlay construction when the sparse trie was reused and the DB tip is already covered by its anchor-to-parent range.
Sourcepub fn with_immediate_state_trie_overlay(
self,
state: Arc<HashedPostStateSorted>,
trie: Arc<TrieUpdatesSorted>,
) -> Self
pub fn with_immediate_state_trie_overlay( self, state: Arc<HashedPostStateSorted>, trie: Arc<TrieUpdatesSorted>, ) -> Self
Sets an immediate hashed-state and trie-updates overlay.
Sourcepub fn build_overlay<Provider>(
&self,
provider: &Provider,
) -> ProviderResult<Overlay>where
Provider: StageCheckpointReader + PruneCheckpointReader + ChangeSetReader + StorageChangeSetReader + DBProvider + BlockNumReader + StorageSettingsCache,
pub fn build_overlay<Provider>(
&self,
provider: &Provider,
) -> ProviderResult<Overlay>where
Provider: StageCheckpointReader + PruneCheckpointReader + ChangeSetReader + StorageChangeSetReader + DBProvider + BlockNumReader + StorageSettingsCache,
Builds the effective overlay for the given provider.
Sourcepub fn build_overlay_at_frontiers<Provider>(
&self,
provider: &Provider,
state_trie_tip_block: BlockNumHash,
finish_tip_block: BlockNumHash,
) -> ProviderResult<Overlay>where
Provider: ChangeSetReader + StorageChangeSetReader + DBProvider + BlockNumReader + StageCheckpointReader + PruneCheckpointReader + StorageSettingsCache,
pub fn build_overlay_at_frontiers<Provider>(
&self,
provider: &Provider,
state_trie_tip_block: BlockNumHash,
finish_tip_block: BlockNumHash,
) -> ProviderResult<Overlay>where
Provider: ChangeSetReader + StorageChangeSetReader + DBProvider + BlockNumReader + StageCheckpointReader + PruneCheckpointReader + StorageSettingsCache,
Builds the effective overlay using frontiers already read from the provider.
This is useful for callers that key an overlay cache by the durable frontiers.