OverlayStateProvider

Struct OverlayStateProvider 

pub struct OverlayStateProvider<Provider, N: NodePrimitives = EthPrimitives> { /* private fields */ }
State provider with lazily resolved state trie and execution overlays.

Implementations

Source

impl<Provider, N: NodePrimitives> OverlayStateProvider<OwnedProvider<Provider>, N>

pub fn new(provider: Provider, overlay_builder: OverlayBuilder<N>) -> Self
where Provider: StorageSettingsCache,

Creates an overlay state provider over an already-open database provider.

Source

impl<'a, Provider, N: NodePrimitives> OverlayStateProvider<&'a Provider, N>

pub fn new_ref( provider: &'a Provider, overlay_builder: OverlayBuilder<N>, ) -> Self
where Provider: StorageSettingsCache,

Creates an overlay state provider over a borrowed database provider.