pub fn anchor_for_parent<N, Provider>(
parent_hash: B256,
in_mem_chain: impl Iterator<Item = ExecutedBlock<N>>,
provider: &Provider,
) -> ProviderResult<AnchorForParent<N>>where
N: NodePrimitives,
Provider: StageCheckpointReader + BlockNumReader + PruneCheckpointReader,Expand description
Returns the anchor block to use for the target parent and a chain of in-memory blocks.
Arguments
parent: The block whose post-state is being targeted.in_mem_chain: Yields the in-memory blocks in the chain, starting atparent_hash.provider: Used to resolve the durable frontiers and check changeset availability.