pub struct OverlayStateProvider<Provider, N: NodePrimitives = EthPrimitives> { /* private fields */ }Expand description
State provider with lazily resolved state trie and execution overlays.
Implementations
Sourceimpl<Provider, N: NodePrimitives> OverlayStateProvider<OwnedProvider<Provider>, N>
impl<Provider, N: NodePrimitives> OverlayStateProvider<OwnedProvider<Provider>, N>
Sourcepub fn new(provider: Provider, overlay_builder: OverlayBuilder<N>) -> Selfwhere
Provider: StorageSettingsCache,
pub fn new(provider: Provider, overlay_builder: OverlayBuilder<N>) -> Selfwhere
Provider: StorageSettingsCache,
Creates an overlay state provider over an already-open database provider.
Sourceimpl<'a, Provider, N: NodePrimitives> OverlayStateProvider<&'a Provider, N>
impl<'a, Provider, N: NodePrimitives> OverlayStateProvider<&'a Provider, N>
Sourcepub fn new_ref(
provider: &'a Provider,
overlay_builder: OverlayBuilder<N>,
) -> Selfwhere
Provider: StorageSettingsCache,
pub fn new_ref(
provider: &'a Provider,
overlay_builder: OverlayBuilder<N>,
) -> Selfwhere
Provider: StorageSettingsCache,
Creates an overlay state provider over a borrowed database provider.